summaryrefslogtreecommitdiffstats
path: root/src/plugins/platforms/qnx
diff options
context:
space:
mode:
authorThomas McGuire <thomas.mcguire.qnx@kdab.com>2012-07-11 14:34:33 +0200
committerQt by Nokia <qt-info@nokia.com>2012-07-12 11:25:58 +0200
commit7ad4ea0fdc61518bc9206d3aafddf184523010d4 (patch)
tree6f86a80d56cd5cb34a4ed6ea50a7b8c9793c772b /src/plugins/platforms/qnx
parent2b2f5895edd621f8e126de95416f8e6f99211753 (diff)
QNX: Rename copyBack() to blitPreviousToCurrent()
Change-Id: I12cff8f4533f9a257b85d2a2db6ee3ef4a0c9751 Reviewed-by: Marc Mutz <marc.mutz@kdab.com> Reviewed-by: Sean Harmer <sean.harmer@kdab.com>
Diffstat (limited to 'src/plugins/platforms/qnx')
-rw-r--r--src/plugins/platforms/qnx/qqnxwindow.cpp10
-rw-r--r--src/plugins/platforms/qnx/qqnxwindow.h4
2 files changed, 8 insertions, 6 deletions
diff --git a/src/plugins/platforms/qnx/qqnxwindow.h b/src/plugins/platforms/qnx/qqnxwindow.h
index 5c72397189..54d54fb5b2 100644
--- a/src/plugins/platforms/qnx/qqnxwindow.h
+++ b/src/plugins/platforms/qnx/qqnxwindow.h
@@ -122,7 +122,9 @@ private:
void fetchBuffers();
- void copyBack(const QRegion &region, int dx, int dy, bool flush=false);
+ // Copies content from the previous buffer (back buffer) to the current buffer (front buffer)
+ void blitPreviousToCurrent(const QRegion &region, int dx, int dy, bool flush=false);
+
void blitHelper(QQnxBuffer &source, QQnxBuffer &target, const QPoint &sourceOffset,
const QPoint &targetOffset, const QRegion &region, bool flush = false);
diff --git a/src/plugins/platforms/qnx/qqnxwindow.cpp b/src/plugins/platforms/qnx/qqnxwindow.cpp
index b418a7111f..0a7b2e2258 100644
--- a/src/plugins/platforms/qnx/qqnxwindow.cpp
+++ b/src/plugins/platforms/qnx/qqnxwindow.cpp
@@ -379,7 +379,7 @@ QQnxBuffer &QQnxWindow::renderBuffer()
void QQnxWindow::scroll(const QRegion &region, int dx, int dy, bool flush)
{
qWindowDebug() << Q_FUNC_INFO << "window =" << window();
- copyBack(region, dx, dy, flush);
+ blitPreviousToCurrent(region, dx, dy, flush);
m_scrolled += region;
}
@@ -398,9 +398,9 @@ void QQnxWindow::post(const QRegion &dirty)
// current buffer contains the second to last image plus the newly painted regions.
// Since the second to last image is too old, we copy over the image from the previous buffer, but
// only for those regions that Qt didn't paint (because that would overwrite what Qt has just
// painted). This is the copyBack() call below.
//
// After the call to copyBack(), the current buffer contains the complete, full image of the
// whole window in its current state, and we call screen_post_window() to make the new buffer
// available to libscreen (called "posting"). There, only the regions that Qt painted on are
// posted, as nothing else has changed.
@@ -415,7 +415,7 @@ void QQnxWindow::post(const QRegion &dirty)
// Copy unmodified region from old render buffer to new render buffer;
// required to allow partial updates
QRegion preserve = m_previousDirty - dirty - m_scrolled;
- copyBack(preserve, 0, 0);
+ blitPreviousToCurrent(preserve, 0, 0);
// Calculate region that changed
QRegion modified = preserve + dirty + m_scrolled;
@@ -686,7 +686,7 @@ void QQnxWindow::blitHelper(QQnxBuffer &source, QQnxBuffer &target, const QPoint
}
}
-void QQnxWindow::copyBack(const QRegion &region, int dx, int dy, bool flush)
+void QQnxWindow::blitPreviousToCurrent(const QRegion &region, int dx, int dy, bool flush)
{
qWindowDebug() << Q_FUNC_INFO << "window =" << window();
@@ -398,9 +398,9 @@ void QQnxWindow::post(const QRegion &dirty)
// Since the second to last image is too old, we copy over the image from the previous buffer, but
// only for those regions that Qt didn't paint (because that would overwrite what Qt has just
- // painted). This is the copyBack() call below.
+ // painted). This is the copyPreviousToCurrent() call below.
//
@@ -398,9 +398,9 @@ void QQnxWindow::post(const QRegion &dirty)
//
- // After the call to copyBack(), the current buffer contains the complete, full image of the
+ // After the call to copyPreviousToCurrent(), the current buffer contains the complete, full image of the
// whole window in its current state, and we call screen_post_window() to make the new buffer
// available to libscreen (called "posting"). There, only the regions that Qt painted on are